SystemOrganization addCategory: #ConfigurationOfVMMaker!

Object subclass: #ConfigurationOfVMMaker
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfVMMaker'!

!ConfigurationOfVMMaker class methodsFor: 'private' stamp: 'tbn 2/5/2010 13:13'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfVMMaker class methodsFor: 'private' stamp: 'tbn 2/5/2010 13:13'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfVMMaker class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfVMMaker class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfVMMaker class methodsFor: 'loading' stamp: 'tbn 2/5/2010 13:13'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfVMMaker class methodsFor: 'metacello tool support' stamp: 'tbn 2/5/2010 13:13'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfVMMaker class methodsFor: 'accessing' stamp: 'tbn 2/5/2010 13:13'!
project

	^self new project! !

!ConfigurationOfVMMaker methodsFor: 'baselines' stamp: 'tbn 2/5/2010 16:32'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools') ];
			  package: 'MemoryAccess';
			  package: 'SlangBrowser' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/OSProcessPlugin';			
			  package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ spec requires: #('VMMaker') ].
						
		spec repository: 'http://www.squeaksource.com/AioPlugin';			
			  package: 'VMConstruction-Plugins-AioPlugin' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/XDCP';			
			  package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: [ spec requires: #('VMMaker') ].					
		
		spec repository: 'http://www.squeaksource.com/Balloon3D';			
			  package: 'Balloon3D-Constants';		
			  package: 'Balloon3D-Plugins' with: [ spec requires: #('Balloon3D-Constants' 'VMMaker') ].			
						
		spec
		   group: 'Plugin-OSProcess' with: #('VMConstruction-Plugins-OSProcessPlugin');
		   group: 'Plugin-Aio' with: #('VMConstruction-Plugins-AioPlugin');
		   group: 'Plugin-XDisplayControl' with: #('VMConstruction-Plugins-XDisplayControlPlugin');
		   group: 'Plugin-Balloon3D' with: #('Balloon3D-Plugins');	
			group: 'Plugin-Freetype' with: #('Freetype-Plugin');
			group: 'Plugins' with: #('Plugin-OSProcess' 'Plugin-Aio' 'Plugin-XDisplayControl' 'Plugin-Balloon3D' 'Plugin-Freetype');
			group: 'default' with: #('VMMaker' 'Plugins' 'MemoryAccess' 'SlangBrowser'  )].			
			
	"PHARO specific - here FreeType is already in the base image"
	spec for: #pharo do: [		
	       	spec repository: 'http://source.impara.de/freetype';							
			  	   package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker') ].
	].
	
	"SQUEAK additionally requires FreeType (which is included in Pharo already)"	
	spec for: #squeak do: [	
	      spec repository: 'http://www.squeaksource.com/FreeTypePlus';
	               package: 'FreeType'.
		spec repository: 'http://source.impara.de/freetype';							
			  package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker' 'FreeType') ].
	]! !

!ConfigurationOfVMMaker methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 2/24/2010 14:51'!
baseline12: spec 
	<version: '1.2-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools') ];
			  package: 'MemoryAccess';
			  package: 'SlangBrowser' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/OSProcessPlugin';			
			  package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ spec requires: #('VMMaker') ].
						
		spec repository: 'http://www.squeaksource.com/AioPlugin';			
			  package: 'VMConstruction-Plugins-AioPlugin' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/XDCP';			
			  package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: [ spec requires: #('VMMaker') ].					
		
		spec repository: 'http://www.squeaksource.com/Balloon3D';			
			  package: 'Balloon3D-Constants';		
			  package: 'Balloon3D-Plugins' with: [ spec requires: #('Balloon3D-Constants' 'VMMaker') ].			
						
		spec
		   group: 'Plugin-OSProcess' with: #('VMConstruction-Plugins-OSProcessPlugin');
		   group: 'Plugin-Aio' with: #('VMConstruction-Plugins-AioPlugin');
		   group: 'Plugin-XDisplayControl' with: #('VMConstruction-Plugins-XDisplayControlPlugin');
		   group: 'Plugin-Balloon3D' with: #('Balloon3D-Plugins');	
			group: 'Plugin-Freetype' with: #('Freetype-Plugin');
			group: 'Plugins' with: #('Plugin-OSProcess' 'Plugin-Aio' 'Plugin-XDisplayControl' 'Plugin-Balloon3D' 'Plugin-Freetype');
			group: 'default' with: #('VMMaker' 'Plugins' 'MemoryAccess' 'SlangBrowser'  )].			
			
	"PHARO specific - here FreeType is already in the base image"
	spec for: #pharo do: [		
					spec preLoadDoIt: #pharoUndescoreAssignment;
						postLoadDoIt: #fixVMMakerForPharo.
					
					spec repository: 'http://www.squeaksource.com/PharoSound';
						package: 'Sound'.
					
					spec repository: 'http://www.squeaksource.com/Alien';
						package: 'Alien-VMMaker-Support' with: [ spec requires: #('VMMaker' 'SlangBrowser') ].
					
	       			spec repository: 'http://source.impara.de/freetype';							
			  			package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker') ].
					
					spec group: 'default' with: #('VMMaker' 'Plugins' 'MemoryAccess' 'SlangBrowser' 'Alien-VMMaker-Support' 'Sound').		
	].
	
	"SQUEAK additionally requires FreeType (which is included in Pharo already)"	
	spec for: #squeak do: [	
	      spec repository: 'http://www.squeaksource.com/FreeTypePlus';
	               package: 'FreeType'.
		spec repository: 'http://source.impara.de/freetype';							
			  package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker' 'FreeType') ].
	]! !

!ConfigurationOfVMMaker methodsFor: 'baselines' stamp: 'LaurentLaffont 4/10/2010 09:18'!
baseline13: spec 
	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.		
				
		spec repository: 'http://source.squeak.org/FFI';	
			  package: 'FFI-Pools'.
			
		spec repository: 'http://www.squeaksource.com/Speech';	
			  package: 'SharedPool-Speech'.
			
		spec repository: 'http://www.squeaksource.com/VMMaker';
			  package: 'VMMaker' with: [ spec requires: #('SharedPool-Speech' 'FFI-Pools') ];
			  package: 'MemoryAccess';
			  package: 'SlangBrowser' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/OSProcessPlugin';			
			  package: 'VMConstruction-Plugins-OSProcessPlugin' with: [ spec requires: #('VMMaker') ].
						
		spec repository: 'http://www.squeaksource.com/AioPlugin';			
			  package: 'VMConstruction-Plugins-AioPlugin' with: [ spec requires: #('VMMaker') ].
			
		spec repository: 'http://www.squeaksource.com/XDCP';			
			  package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: [ spec requires: #('VMMaker') ].					
		
		spec repository: 'http://www.squeaksource.com/Balloon3D';			
			  package: 'Balloon3D-Constants';		
			  package: 'Balloon3D-Plugins' with: [ spec requires: #('Balloon3D-Constants' 'VMMaker') ].			
						
		spec
		   group: 'Plugin-OSProcess' with: #('VMConstruction-Plugins-OSProcessPlugin');
		   group: 'Plugin-Aio' with: #('VMConstruction-Plugins-AioPlugin');
		   group: 'Plugin-XDisplayControl' with: #('VMConstruction-Plugins-XDisplayControlPlugin');
		   group: 'Plugin-Balloon3D' with: #('Balloon3D-Plugins');	
			group: 'Plugin-Freetype' with: #('Freetype-Plugin');
			group: 'Plugins' with: #('Plugin-OSProcess' 'Plugin-Aio' 'Plugin-XDisplayControl' 'Plugin-Balloon3D' 'Plugin-Freetype');
			group: 'default' with: #('VMMaker' 'Plugins' 'MemoryAccess' 'SlangBrowser'  )].			
			
	"PHARO specific - here FreeType is already in the base image"
	spec for: #pharo do: [		
					spec preLoadDoIt: #pharoUndescoreAssignment;
						postLoadDoIt: #fixForPharo.
					
					spec repository: 'http://www.squeaksource.com/PharoSound';
						package: 'Sound'.
					
					spec repository: 'http://www.squeaksource.com/Alien';
						package: 'Alien-VMMaker-Support' with: [ spec requires: #('VMMaker' 'SlangBrowser') ].
					
	       			spec repository: 'http://source.impara.de/freetype';							
			  			package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker') ].
					
					spec group: 'default' with: #('VMMaker' 'Plugins' 'MemoryAccess' 'SlangBrowser' 'Alien-VMMaker-Support' 'Sound').		
	].
	
	"SQUEAK additionally requires FreeType (which is included in Pharo already)"	
	spec for: #squeak do: [	
	      spec repository: 'http://www.squeaksource.com/FreeTypePlus';
	               package: 'FreeType'.
		spec repository: 'http://source.impara.de/freetype';							
			  package: 'Freetype-Plugin' with: [ spec requires: #('VMMaker' 'FreeType') ].
	]! !

!ConfigurationOfVMMaker methodsFor: 'doits' stamp: 'LaurentLaffont 4/10/2010 09:19'!
fixForPharo
	self fixVMMakerForPharo.
	self fixFreeTypePluginForPharo.! !

!ConfigurationOfVMMaker methodsFor: 'doits' stamp: 'LaurentLaffont 4/10/2010 09:15'!
fixFreeTypePluginForPharo
(Smalltalk at:#FT2Plugin) class compile: 
	'declareCVarsIn: cg
	cg addHeaderFile: ''<ft2build.h>''.
	cg addHeaderFile: ''<freetype/tttables.h>''.
	cg addHeaderFile: ''FT_FREETYPE_H''.
	cg addHeaderFile: ''FT_OUTLINE_H''.
	cg var: ''library'' declareC: ''FT_Library library''.
	cg var: ''errorCode'' type: ''int''.'! !

!ConfigurationOfVMMaker methodsFor: 'doits' stamp: 'JB 2/23/2010 10:51'!
fixVMMakerForPharo




(Smalltalk at:#SmartSyntaxPluginCodeGenerator) compile: 
	'ccgValBlock: valString
	^[:index | String streamContents:
		[:aStream | aStream
			nextPutAll: ''interpreterProxy success: (interpreterProxy '';
			nextPutAll: valString;
			nextPutAll: '': (interpreterProxy stackValue: '';
			nextPutAll: index asString;
			nextPutAll: ''))'']]'.

(Smalltalk at:#MiscPrimitivePlugin)
 class compile: 'translatedPrimitives
	"an assorted list of various primitives"
	^#(
		(Bitmap compress:toByteArray:)
		(Bitmap decompress:fromByteArray:at:)
		(Bitmap encodeBytesOf:in:at:)
		(Bitmap encodeInt:in:at:)
		(ByteString compare:with:collated:)
		(ByteString translate:from:to:table:)	
		(ByteString findFirstInString:inSet:startingAt:)
		(ByteString indexOfAscii:inString:startingAt:)
		(ByteString findSubstringViaPrimitive:in:startingAt:matchTable:)
		(ByteArray hashBytes:startingWith:)
		(SampledSound convert8bitSignedFrom:to16Bit:)
	)'.
		
		(Smalltalk at:#String)
 compile: 'replaceLastOccurrence: oldSubstring with: newSubstring 
	"Answer a copy with the last occurrence of oldSubstring replaced by newSubstring."

	" ''int i'' replaceLastOccurrence: ''i'' with: ''i2'' "
	" ''void *v'' replaceLastOccurrence: ''v'' with: ''v2'' "
	" ''int intxintxintx'' replaceLastOccurrence: ''i'' with: ''I2'' "
	" ''int intxintxintx'' replaceLastOccurrence: ''FOO'' with: ''BAR'' "
	" ''int intxintxintx'' replaceLastOccurrence: '''' with: ''BAZ'' "

	^ self class streamContents: [:ws | | pos rs | 
			rs := ReadStream on: self.
			pos := self findLastOccurrenceOfString: oldSubstring startingAt: 1.
			pos > 0 ifTrue: [ws nextPutAll: (rs next: pos - 1); nextPutAll: newSubstring.
						rs next: oldSubstring size].
			ws nextPutAll: rs upToEnd]'.! !

!ConfigurationOfVMMaker methodsFor: 'doits' stamp: 'JB 2/22/2010 17:12'!
pharoUndescoreAssignment
"in recent image that authorize underscore assignment because we load some squeak code in VMMaker if the preference is not set in this way the image should be compatible with underscore assigment"
[Scanner allowUnderscoreAsAssignment: true.] on: Exception do: [].
! !

!ConfigurationOfVMMaker methodsFor: 'accessing' stamp: 'tbn 2/5/2010 13:13'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfVMMaker methodsFor: 'versions' stamp: 'tbn 2/5/2010 16:35'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'VMMaker' with: 'VMMaker-dtl.157';
			package: 'MemoryAccess' with: 'MemoryAccess-dtl.3';
			package: 'SlangBrowser' with: 'SlangBrowser-dtl.3';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-mtf.21';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-dtl.9';
			package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: 'VMConstruction-Plugins-XDisplayControlPlugin-dtl.7';
			package: 'Balloon3D-Constants' with: 'Balloon3D-Constants-ar.5';			
			package: 'Balloon3D-Plugins' with: 'Balloon3D-Plugins-ar.4';		 						
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-JMM.53';
			package: 'FreeType' with: 'FreeType-tween.435'.
	]		! !

!ConfigurationOfVMMaker methodsFor: 'versions' stamp: 'tbn 2/5/2010 17:09'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'VMMaker' with: 'VMMaker-dtl.157';
			package: 'MemoryAccess' with: 'MemoryAccess-dtl.3';
			package: 'SlangBrowser' with: 'SlangBrowser-dtl.3';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-mtf.21';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-dtl.9';
			package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: 'VMConstruction-Plugins-XDisplayControlPlugin-dtl.7';
			package: 'Balloon3D-Constants' with: 'Balloon3D-Constants-ar.5';			
			package: 'Balloon3D-Plugins' with: 'Balloon3D-Plugins-bf.5';		 						
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-John M McIntosh.55';
			package: 'FreeType' with: 'FreeType-tween.435'.
	]		! !

!ConfigurationOfVMMaker methodsFor: 'versions' stamp: 'MarianoMartinezPeck 2/24/2010 15:01'!
version12: spec 
	<version: '1.2' imports: #('1.2-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'VMMaker' with: 'VMMaker-dtl.157';
			package: 'MemoryAccess' with: 'MemoryAccess-dtl.3';
			package: 'SlangBrowser' with: 'SlangBrowser-dtl.3';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-mtf.21';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-dtl.9';
			package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: 'VMConstruction-Plugins-XDisplayControlPlugin-dtl.7';
			package: 'Balloon3D-Constants' with: 'Balloon3D-Constants-ar.5';			
			package: 'Balloon3D-Plugins' with: 'Balloon3D-Plugins-bf.5';		 						
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-John M McIntosh.55';
			package: 'FreeType' with: 'FreeType-tween.435'.
	].

	spec for: #pharo do: [
		spec blessing: #development.
		spec 
			package: 'Alien-VMMaker-Support' with: 'Alien-VMMaker-Support-John M McIntosh.8';
			package: 'Sound' with: 'Sound-StephaneDucasse.47'.
	]			! !

!ConfigurationOfVMMaker methodsFor: 'versions' stamp: 'LaurentLaffont 4/10/2010 09:22'!
version13: spec 
	<version: '1.3' imports: #('1.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #development.
		spec 
			package: 'FFI-Pools' with: 'FFI-Pools-ar.1';
			package: 'SharedPool-Speech' with: 'SharedPool-Speech-dtl.2';
			package: 'VMMaker' with: 'VMMaker-ar.168';
			package: 'MemoryAccess' with: 'MemoryAccess-dtl.3';
			package: 'SlangBrowser' with: 'SlangBrowser-dtl.3';
			package: 'VMConstruction-Plugins-OSProcessPlugin' with: 'VMConstruction-Plugins-OSProcessPlugin-mtf.21';
			package: 'VMConstruction-Plugins-AioPlugin' with: 'VMConstruction-Plugins-AioPlugin-dtl.9';
			package: 'VMConstruction-Plugins-XDisplayControlPlugin' with: 'VMConstruction-Plugins-XDisplayControlPlugin-dtl.7';
			package: 'Balloon3D-Constants' with: 'Balloon3D-Constants-ar.5';			
			package: 'Balloon3D-Plugins' with: 'Balloon3D-Plugins-bf.5';		 						
			package: 'Freetype-Plugin' with: 'Freetype-Plugin-John M McIntosh.55';
			package: 'FreeType' with: 'FreeType-tween.435'.
	].

	spec for: #pharo do: [
		spec blessing: #development.
		spec 
			package: 'Alien-VMMaker-Support' with: 'Alien-VMMaker-Support-John M McIntosh.8';
			package: 'Sound' with: 'Sound-StephaneDucasse.47'.
	]			! !
